@@ -1,5 +1,5 @@
 # pick Nrepeats random tip subsets of specific size
-pick_random_tips = function(tree, size=1, Nsubsets=1, with_replacement=TRUE, drop=TRUE){ 
+pick_random_tips = function(tree, size=1, Nsubsets=1, with_replacement=TRUE, drop_dims=TRUE){ 
 	Ntips  = length(tree$tip.label);
 	if(size>Ntips) stop(sprintf("ERROR: Requested size (%d) exceeds the number of tips in the tree (%d)",size,Ntips))
 		
@@ -13,6 +13,6 @@ pick_random_tips = function(tree, size=1, Nsubsets=1, with_replacement=TRUE, dro
 											
 	# Note that random_tips is a 2D array of size Nsubsets x size in row-major format
 	# So expand to 2D matrix if needed
-	tips = 1L + as.integer(if(drop && Nsubsets==1) random_tips else matrix(random_tips, ncol=size, byrow=TRUE));
+	tips = 1L + as.integer(if(drop_dims && Nsubsets==1) random_tips else matrix(random_tips, ncol=size, byrow=TRUE));
 	return(tips);
 }
\ No newline at end of file
